#
# spec file for package virt-v2v
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needsbinariesforbuild


# If there are patches which touch autotools files, set this to 1.
%global patches_touch_autotools 1
# The source directory.
%global source_directory 1.44-stable
Name:           virt-v2v
Version:        1.44.2
Release:        150400.3.6.1
Summary:        Tools to convert a virtual machine to run on KVM
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://github.com/libguestfs/virt-v2v
Patch0:         fix-linker-error.patch
Patch1:         CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
Patch2:         Add-support-for-Zstandard-compressed-kernel-modules.patch
Source0:        https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz
Source1:        https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz.sig
BuildRequires:  augeas-devel
BuildRequires:  file-devel
#BuildRequires: /usr/bin/pod2man
BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel
BuildRequires:  libguestfs-devel >= 1.42
BuildRequires:  libjansson-devel
BuildRequires:  libosinfo-devel
BuildRequires:  libvirt-devel
BuildRequires:  libxml2-devel
BuildRequires:  mkisofs
BuildRequires:  ocaml >= 4.01
BuildRequires:  ocaml-fileutils-devel
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-gettext-devel
BuildRequires:  ocaml-gettext-stub-devel
BuildRequires:  ocaml-hivex-devel
BuildRequires:  ocaml-libguestfs
BuildRequires:  ocaml-libguestfs-devel
BuildRequires:  ocaml-libvirt-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  qemu-tools
BuildRequires:  perl(Sys::Guestfs)
BuildRequires:  pkgconfig(bash-completion) >= 2.0
Requires:       %{_bindir}/gawk
Requires:       %{_bindir}/gzip
Requires:       %{_bindir}/virsh
Requires:       curl
Requires:       guestfs-tools >= 1.42
Requires:       libguestfs0%{?_isa} >= 1.42
Requires:       unzip
Recommends:     nbdkit
Recommends:     nbdkit-curl-plugin
Recommends:     nbdkit-python-plugin
Recommends:     nbdkit-ssh-plugin
Recommends:     nbdkit-vddk-plugin
# libguestfs hasn't been built on i686 for a while since there is no
# kernel built for this architecture any longer and libguestfs rather
# fundamentally depends on the kernel.  Therefore we must exclude this
# arch.  Note there is no bug filed for this because we do not ever
# expect that libguestfs or virt-v2v will be available on i686 so
# there is nothing that needs fixing.
ExcludeArch:    %{ix86}
%if 0%{patches_touch_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%endif

%description
Virt-v2v converts a single guest from a foreign hypervisor to run on
KVM.  It can read Linux and Windows guests running on VMware, Xen,
Hyper-V and some other hypervisors, and convert them to KVM managed by
libvirt, OpenStack, oVirt, Red Hat Virtualisation (RHV) or several
other targets.  It can modify the guest to make it bootable on KVM and
install virtio drivers so it will run quickly.

%package bash-completion
Summary:        Bash tab-completion for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
Requires:       bash-completion >= 2.0
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.

%package man-pages-ja
Summary:        Japanese (ja) man pages for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.

%package man-pages-uk
Summary:        Ukrainian (uk) man pages for %{name}
Group:          System/Management
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.

%prep
%autosetup -p1
%if 0%{patches_touch_autotools}
autoreconf -i
%endif

%build
%configure
%make_build

%install
%make_install

# Delete libtool crap.
find %{buildroot} -type f -name "*.la" -delete -print

# Virt-tools data directory.  This contains a symlink to rhsrvany.exe
# which is satisfied by the dependency on mingw32-srvany.
mkdir -p %{buildroot}/%{_datadir}/virt-tools

# Delete the v2v test harness (except for the man page).
rm -r %{buildroot}/%{_libdir}/ocaml/v2v_test_harness
rm -r %{buildroot}/%{_libdir}/ocaml/stublibs/dllv2v_test_harness*

# Find locale files.
%find_lang %{name}

%check
# All tests fail at the moment because of bugs in libvirt blockdev.
# # Tests fail on both armv7 and ppc64le in Fedora 31 because the kernel
# # cannot boot on qemu.
# %ifnarch %{arm} ppc64le

# # On x86_64 this single test fails with: "virt-v2v: warning: the
# # target hypervisor does not support a x86_64 KVM guest".  Missing
# # BuildRequires?
# %ifarch x86_64
# truncate -s 0 tests/test-v2v-o-libvirt.sh
# %endif

# # This test fails in mock.
# truncate -s 0 tests/test-v2v-oa-option.sh

# # Make sure we can see the debug messages (RHBZ#1230160).
# export LIBGUESTFS_DEBUG=1
# export LIBGUESTFS_TRACE=1

# make %{?_smp_mflags} check || {
#     cat tests/test-suite.log
#     exit 1
#   }

# %endif

%files -f %{name}.lang
%license COPYING
#doc README
%{_bindir}/virt-v2v
%{_bindir}/virt-v2v-copy-to-local
%{_mandir}/man1/virt-v2v.1%{?ext_man}
%{_mandir}/man1/virt-v2v-copy-to-local.1%{?ext_man}
%{_mandir}/man1/virt-v2v-hacking.1%{?ext_man}
%{_mandir}/man1/virt-v2v-input-vmware.1%{?ext_man}
%{_mandir}/man1/virt-v2v-input-xen.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-local.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-openstack.1%{?ext_man}
%{_mandir}/man1/virt-v2v-output-rhv.1%{?ext_man}
%{_mandir}/man1/virt-v2v-release-notes-1.42.1%{?ext_man}
%{_mandir}/man1/virt-v2v-support.1%{?ext_man}
%{_mandir}/man1/virt-v2v-test-harness.1%{?ext_man}
%{_datadir}/virt-tools

%files bash-completion
%license COPYING
%{_datadir}/bash-completion/completions/virt-v2v
%{_datadir}/bash-completion/completions/virt-v2v-copy-to-local

%files man-pages-ja
%license COPYING
%lang(ja) %{_mandir}/ja/man1/*.1*
%dir %{_mandir}/ja
%dir %{_mandir}/ja/man1/

%files man-pages-uk
%license COPYING
%lang(uk) %{_mandir}/uk/man1/*.1*
%dir %{_mandir}/uk
%dir %{_mandir}/uk/man1/

%changelog
* Thu Nov 30 2023 carnold@suse.com
- bsc#1216068 - virt-v2v fails due to zstd module compression
  Add-support-for-Zstandard-compressed-kernel-modules.patch
* Wed Jun 29 2022 carnold@suse.com
- bsc#1201064 - Libguestfs: Buffer overflow in get_keys leads
  to DOS - CVE-2022-2211
  CVE-2022-2211-options-fix-buffer-overflow-in-get_keys.patch
* Thu Jan  6 2022 carnold@suse.com
- Update to version 1.44.2
  * This is a bug fix release
  virt-v2v-1.44.2.tar.gz.sig
- Drop virt-v2v-1.44.0.tar.gz.sig
* Thu Sep 16 2021 carnold@suse.com
- Fix ocaml linker error due to unresolved 'rpl_free'. For
  comparison, see libguestfs commit 489b14b75e.
  fix-linker-error.patch
* Fri May  7 2021 carnold@suse.com
- Update to version 1.44.0
  Include virt-v2v-1.44.0.tar.gz.sig
  * windows: Allow qxldod.inf as synonym for qxl.inf
  * -i ova: Set LANG=C and --no-auto-compress when running tar.
  * Increase required free space in Windows to 100 MB
  * Tidy up error messages when mounting a virtio-win ISO
* Thu Apr 29 2021 predivan@mts.rs
- Update to version 1.43.5
  * No upstream provided Changelog
- Package changes
  * Switch BuildRequires pcre-devel to pcre2-devel
  * Ran spec-cleaner
* Wed Feb 10 2021 jengelh@inai.de
- Remove old specfile macros and constructs.
* Thu Jan 28 2021 carnold@suse.com
- Update to version 1.43.3
  * Support for ALT Linux 9 and up added
  * Many upstream bug fixes
  * Language file fixes and updates
* Thu Dec  3 2020 predivan@mts.rs
- Update to version 1.43.2
  * No upstream provided Changelog.
* Thu Oct  1 2020 predivan@mts.rs
-  Fix rpmbuild 'directories not owned by package' error on Leap
-  Fix Requires referencing  wrong/non-existing packages
* Mon Jul 20 2020 carnold@suse.com
- Update to version 1.43.1
  * Several bug fixes
- Drop fix-redefinition-error.patch
* Tue May  5 2020 carnold@suse.com
- Fix error: redefinition of 'glib_autoptr_clear_OsinfoList'
  fix-redefinition-error.patch
* Wed Apr 22 2020 carnold@suse.com
- Initial package of virt-v2v version 1.42.0
  * The rhv-upload output mode of virt-v2v is not listed as output
    driver, as virt-p2v does not provide all the GUI elements to
    properly use it
  * Virt-v2v is checked as requirement for the functional tests,
    in addition to guestfish, and virt-customize
  * Virt-p2v-make-disk now sets p2v.local as hostname in the
    generated disk image
  * Document p2v as initial password for the root user on the disk
    image generated by virt-p2v-make-disk, virt-p2v-make-kickstart,
    and virt-p2v-make-kiwi
